@@ -3,6 +3,7 @@
 Most routines work round some numpy oddities in floating point precision and
 casting.  Others work round numpy casting to and from python ints
 """
+
 from __future__ import annotations
 
 import warnings
@@ -50,11 +51,11 @@ sctypes_aliases = {
     getattr(np, dtype)
     for dtype in (
         'int8', 'byte', 'int16', 'short', 'int32', 'intc', 'int_', 'int64', 'longlong',
-        'uint8', 'ubyte', 'uint16', 'ushort', 'uint32', 'uintc', 'uint', 'uint64', 'ulonglong',  # noqa: E501
-        'float16', 'half', 'float32', 'single', 'float64', 'double', 'float96', 'float128', 'longdouble',  # noqa: E501
-        'complex64', 'csingle', 'complex128', 'cdouble', 'complex192', 'complex256', 'clongdouble',  # noqa: E501
+        'uint8', 'ubyte', 'uint16', 'ushort', 'uint32', 'uintc', 'uint', 'uint64', 'ulonglong',
+        'float16', 'half', 'float32', 'single', 'float64', 'double', 'float96', 'float128', 'longdouble',
+        'complex64', 'csingle', 'complex128', 'cdouble', 'complex192', 'complex256', 'clongdouble',
         # other names of the built-in scalar types
-        'int_', 'float_', 'complex_', 'bytes_', 'str_', 'bool_', 'datetime64', 'timedelta64',  # noqa: E501
+        'int_', 'float_', 'complex_', 'bytes_', 'str_', 'bool_', 'datetime64', 'timedelta64',
         # other
         'object_', 'void',
     )
@@ -274,7 +275,13 @@ def type_info(np_type):
             nexp=None,
             width=width,
         )
-    info = np.finfo(dt)
+    # Mitigate warning from WSL1 when checking `np.longdouble` (#1309)
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
+            action='ignore', category=UserWarning, message='Signature.*numpy.longdouble'
+        )
+        info = np.finfo(dt)
+
     # Trust the standard IEEE types
     nmant, nexp = info.nmant, info.nexp
     ret = dict(
@@ -611,7 +618,7 @@ def int_abs(arr):
     >>> int_abs(np.array([-128, 127], dtype=np.float32))
     array([128., 127.], dtype=float32)
     """
-    arr = np.array(arr, copy=False)
+    arr = np.asarray(arr)
     dt = arr.dtype
     if dt.kind == 'u':
         return arr
@@ -757,7 +764,7 @@ def able_int_type(values):
     >>> able_int_type([-1, 1]) == np.int8
     True
     """
-    if any([v % 1 for v in values]):
+    if any(v % 1 for v in values):
         return None
     mn = min(values)
     mx = max(values)
