@@ -22,19 +22,25 @@ from nibabel.processing import conform
 def _get_parser():
     """Return command-line argument parser."""
     p = argparse.ArgumentParser(description=__doc__)
-    p.add_argument("infile",
-                   help="Neuroimaging volume to conform.")
-    p.add_argument("outfile",
-                   help="Name of output file.")
-    p.add_argument("--out-shape", nargs=3, default=(256, 256, 256), type=int,
-                   help="Shape of the conformed output.")
-    p.add_argument("--voxel-size", nargs=3, default=(1, 1, 1), type=int,
-                   help="Voxel size in millimeters of the conformed output.")
-    p.add_argument("--orientation", default="RAS",
-                   help="Orientation of the conformed output.")
-    p.add_argument("-f", "--force", action="store_true",
-                   help="Overwrite existing output files.")
-    p.add_argument("-V", "--version", action="version", version=f"{p.prog} {__version__}")
+    p.add_argument('infile', help='Neuroimaging volume to conform.')
+    p.add_argument('outfile', help='Name of output file.')
+    p.add_argument(
+        '--out-shape',
+        nargs=3,
+        default=(256, 256, 256),
+        type=int,
+        help='Shape of the conformed output.',
+    )
+    p.add_argument(
+        '--voxel-size',
+        nargs=3,
+        default=(1, 1, 1),
+        type=int,
+        help='Voxel size in millimeters of the conformed output.',
+    )
+    p.add_argument('--orientation', default='RAS', help='Orientation of the conformed output.')
+    p.add_argument('-f', '--force', action='store_true', help='Overwrite existing output files.')
+    p.add_argument('-V', '--version', action='version', version=f'{p.prog} {__version__}')
 
     return p
 
@@ -46,7 +52,7 @@ def main(args=None):
     from_img = load(opts.infile)
 
     if not opts.force and Path(opts.outfile).exists():
-        raise FileExistsError(f"Output file exists: {opts.outfile}")
+        raise FileExistsError(f'Output file exists: {opts.outfile}')
 
     out_img = conform(
         from_img=from_img,
@@ -54,6 +60,7 @@ def main(args=None):
         voxel_size=opts.voxel_size,
         order=3,
         cval=0.0,
-        orientation=opts.orientation)
+        orientation=opts.orientation,
+    )
 
     save(out_img, opts.outfile)
