@@ -8,9 +8,6 @@
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 
-import sys
-from io import StringIO
-
 import numpy as np
 
 from nibabel import Nifti1Image
