@@ -25,6 +25,7 @@ and compare against command line output of::
 
     mincstats my_funny.mnc
 """
+
 import warnings
 
 import numpy as np
@@ -163,7 +164,7 @@ class Minc2Image(Minc1Image):
     def from_file_map(klass, file_map, *, mmap=True, keep_file_open=None):
         # Import of h5py might take awhile for MPI-enabled builds
         # So we are importing it here "on demand"
-        import h5py  # type: ignore
+        import h5py  # type: ignore[import]
 
         holder = file_map['image']
         if holder.filename is None:
