@@ -1,11 +1,9 @@
-"""Testing Siemens "ASCCONV" parser
-"""
+"""Testing Siemens "ASCCONV" parser"""
 
 from collections import OrderedDict
 from os.path import dirname
 from os.path import join as pjoin
 
-import numpy as np
 from numpy.testing import assert_array_almost_equal, assert_array_equal
 
 from .. import ascconv
