@@ -1,8 +1,7 @@
-"""Testing DICOM wrappers
-"""
+"""Testing DICOM wrappers"""
 
 import gzip
-from copy import copy
+from copy import deepcopy
 from decimal import Decimal
 from hashlib import sha1
 from os.path import dirname
@@ -64,8 +63,8 @@ def test_wrappers():
     # test direct wrapper calls
     # first with empty or minimal data
     multi_minimal = {
-        'PerFrameFunctionalGroupsSequence': [None],
-        'SharedFunctionalGroupsSequence': [None],
+        'PerFrameFunctionalGroupsSequence': [pydicom.Dataset()],
+        'SharedFunctionalGroupsSequence': [pydicom.Dataset()],
     }
     for maker, args in (
         (didw.Wrapper, ({},)),
@@ -164,10 +163,10 @@ def test_wrapper_from_data():
     fake_data['SOPClassUID'] = '1.2.840.10008.5.1.4.1.1.4.1'
     with pytest.raises(didw.WrapperError):
         didw.wrapper_from_data(fake_data)
-    fake_data['PerFrameFunctionalGroupsSequence'] = [None]
+    fake_data['PerFrameFunctionalGroupsSequence'] = [pydicom.Dataset()]
     with pytest.raises(didw.WrapperError):
         didw.wrapper_from_data(fake_data)
-    fake_data['SharedFunctionalGroupsSequence'] = [None]
+    fake_data['SharedFunctionalGroupsSequence'] = [pydicom.Dataset()]
     # minimal set should now be met
     dw = didw.wrapper_from_data(fake_data)
     assert dw.is_multiframe
@@ -365,7 +364,7 @@ def test_decimal_rescale():
     assert dw.get_data().dtype != np.dtype(object)
 
 
-def fake_frames(seq_name, field_name, value_seq):
+def fake_frames(seq_name, field_name, value_seq, frame_seq=None):
     """Make fake frames for multiframe testing
 
     Parameters
@@ -376,6 +375,8 @@ def fake_frames(seq_name, field_name, value_seq):
         name of field within sequence
     value_seq : length N sequence
         sequence of values
+    frame_seq : length N list
+        previous result from this function to update
 
     Returns
     -------
@@ -383,23 +384,33 @@ def fake_frames(seq_name, field_name, value_seq):
         each element in list is obj.<seq_name>[0].<field_name> =
         value_seq[n] for n in range(N)
     """
-
-    class Fake:
-        pass
-
-    frames = []
-    for value in value_seq:
-        fake_frame = Fake()
-        fake_element = Fake()
+    if frame_seq is None:
+        frame_seq = [pydicom.Dataset() for _ in range(len(value_seq))]
+    for value, fake_frame in zip(value_seq, frame_seq):
+        if value is None:
+            continue
+        if hasattr(fake_frame, seq_name):
+            fake_element = getattr(fake_frame, seq_name)[0]
+        else:
+            fake_element = pydicom.Dataset()
+            setattr(fake_frame, seq_name, [fake_element])
         setattr(fake_element, field_name, value)
-        setattr(fake_frame, seq_name, [fake_element])
-        frames.append(fake_frame)
-    return frames
+    return frame_seq
 
 
-def fake_shape_dependents(div_seq, sid_seq=None, sid_dim=None):
+def fake_shape_dependents(
+    div_seq,
+    sid_seq=None,
+    sid_dim=None,
+    ipp_seq=None,
+    slice_dim=None,
+    flip_ipp_idx_corr=False,
+):
     """Make a fake dictionary of data that ``image_shape`` is dependent on.
 
+    If you are providing the ``ipp_seq`` argument, they should be generated using
+    a slice normal aligned with the z-axis (i.e. iop == (0, 1, 0, 1, 0, 0)).
+
     Parameters
     ----------
     div_seq : list of tuples
@@ -408,39 +419,92 @@ def fake_shape_dependents(div_seq, sid_seq=None, sid_dim=None):
         list of values to use for the `StackID` of each frame.
     sid_dim : int
         the index of the column in 'div_seq' to use as 'sid_seq'
+    ipp_seq : list of tuples
+        list of values to use for `ImagePositionPatient` for each frame
+    slice_dim : int
+        the index of the column in 'div_seq' corresponding to slices
+    flip_ipp_idx_corr : bool
+        generate ipp values so slice location is negatively correlated with slice index
     """
 
-    class DimIdxSeqElem:
+    class PrintBase:
+        def __repr__(self):
+            attr_strs = [
+                f'{attr}={getattr(self, attr)}' for attr in dir(self) if attr[0].isupper()
+            ]
+            return f"{self.__class__.__name__}({', '.join(attr_strs)})"
+
+    class DimIdxSeqElem(pydicom.Dataset):
         def __init__(self, dip=(0, 0), fgp=None):
+            super().__init__()
             self.DimensionIndexPointer = dip
             if fgp is not None:
                 self.FunctionalGroupPointer = fgp
 
-    class FrmContSeqElem:
+    class FrmContSeqElem(pydicom.Dataset):
         def __init__(self, div, sid):
+            super().__init__()
             self.DimensionIndexValues = div
             self.StackID = sid
 
-    class PerFrmFuncGrpSeqElem:
-        def __init__(self, div, sid):
+    class PlnPosSeqElem(pydicom.Dataset):
+        def __init__(self, ipp):
+            super().__init__()
+            self.ImagePositionPatient = ipp
+
+    class PlnOrientSeqElem(pydicom.Dataset):
+        def __init__(self, iop):
+            super().__init__()
+            self.ImageOrientationPatient = iop
+
+    class PerFrmFuncGrpSeqElem(pydicom.Dataset):
+        def __init__(self, div, sid, ipp, iop):
+            super().__init__()
             self.FrameContentSequence = [FrmContSeqElem(div, sid)]
+            self.PlanePositionSequence = [PlnPosSeqElem(ipp)]
+            self.PlaneOrientationSequence = [PlnOrientSeqElem(iop)]
 
     # if no StackID values passed in then use the values at index 'sid_dim' in
     # the value for DimensionIndexValues for it
+    n_indices = len(div_seq[0])
     if sid_seq is None:
         if sid_dim is None:
             sid_dim = 0
         sid_seq = [div[sid_dim] for div in div_seq]
-    # create the DimensionIndexSequence
+    # Determine slice_dim and create per-slice ipp information
+    if slice_dim is None:
+        slice_dim = 1 if sid_dim == 0 else 0
     num_of_frames = len(div_seq)
-    dim_idx_seq = [DimIdxSeqElem()] * num_of_frames
+    frame_slc_indices = np.array(div_seq)[:, slice_dim]
+    uniq_slc_indices = np.unique(frame_slc_indices)
+    n_slices = len(uniq_slc_indices)
+    iop_seq = [[0.0, 1.0, 0.0, 1.0, 0.0, 0.0] for _ in range(num_of_frames)]
+    if ipp_seq is None:
+        slc_locs = np.linspace(-1.0, 1.0, n_slices)
+        if flip_ipp_idx_corr:
+            slc_locs = slc_locs[::-1]
+        slc_idx_loc = {
+            div_idx: slc_locs[arr_idx] for arr_idx, div_idx in enumerate(np.sort(uniq_slc_indices))
+        }
+        ipp_seq = [[-1.0, -1.0, slc_idx_loc[idx]] for idx in frame_slc_indices]
+    else:
+        assert flip_ipp_idx_corr is False  # caller can flip it themselves
+        assert len(ipp_seq) == num_of_frames
+    # create the DimensionIndexSequence
+    dim_idx_seq = [DimIdxSeqElem()] * n_indices
+    # Add entry for InStackPositionNumber to DimensionIndexSequence
+    fcs_tag = pydicom.datadict.tag_for_keyword('FrameContentSequence')
+    isp_tag = pydicom.datadict.tag_for_keyword('InStackPositionNumber')
+    dim_idx_seq[slice_dim] = DimIdxSeqElem(isp_tag, fcs_tag)
     # add an entry for StackID into the DimensionIndexSequence
     if sid_dim is not None:
         sid_tag = pydicom.datadict.tag_for_keyword('StackID')
-        fcs_tag = pydicom.datadict.tag_for_keyword('FrameContentSequence')
         dim_idx_seq[sid_dim] = DimIdxSeqElem(sid_tag, fcs_tag)
     # create the PerFrameFunctionalGroupsSequence
-    frames = [PerFrmFuncGrpSeqElem(div, sid) for div, sid in zip(div_seq, sid_seq)]
+    frames = [
+        PerFrmFuncGrpSeqElem(div, sid, ipp, iop)
+        for div, sid, ipp, iop in zip(div_seq, sid_seq, ipp_seq, iop_seq)
+    ]
     return {
         'NumberOfFrames': num_of_frames,
         'DimensionIndexSequence': dim_idx_seq,
@@ -448,48 +512,84 @@ def fake_shape_dependents(div_seq, sid_seq=None, sid_dim=None):
     }
 
 
+if have_dicom:
+
+    class FakeDataset(pydicom.Dataset):
+        pixel_array = None
+
+
 class TestMultiFrameWrapper(TestCase):
     # Test MultiframeWrapper
-    MINIMAL_MF = {
+
+    if have_dicom:
         # Minimal contents of dcm_data for this wrapper
-        'PerFrameFunctionalGroupsSequence': [None],
-        'SharedFunctionalGroupsSequence': [None],
-    }
-    WRAPCLASS = didw.MultiframeWrapper
+        MINIMAL_MF = FakeDataset()
+        MINIMAL_MF.PerFrameFunctionalGroupsSequence = [pydicom.Dataset()]
+        MINIMAL_MF.SharedFunctionalGroupsSequence = [pydicom.Dataset()]
+        WRAPCLASS = didw.MultiframeWrapper
 
     @dicom_test
     def test_shape(self):
         # Check the shape algorithm
-        fake_mf = copy(self.MINIMAL_MF)
+        fake_mf = deepcopy(self.MINIMAL_MF)
         MFW = self.WRAPCLASS
         dw = MFW(fake_mf)
         # No rows, cols, raise WrapperError
         with pytest.raises(didw.WrapperError):
             dw.image_shape
-        fake_mf['Rows'] = 64
+        fake_mf.Rows = 64
         with pytest.raises(didw.WrapperError):
             dw.image_shape
         fake_mf.pop('Rows')
-        fake_mf['Columns'] = 64
+        fake_mf.Columns = 64
         with pytest.raises(didw.WrapperError):
             dw.image_shape
-        fake_mf['Rows'] = 32
-        # Missing frame data, raise AssertionError
-        with pytest.raises(AssertionError):
+        fake_mf.Rows = 32
+        # No frame data raises WrapperError
+        with pytest.raises(didw.WrapperError):
             dw.image_shape
-        fake_mf['NumberOfFrames'] = 4
-        # PerFrameFunctionalGroupsSequence does not match NumberOfFrames
-        with pytest.raises(AssertionError):
-            dw.image_shape
-        # check 3D shape when StackID index is 0
+        # check 2D shape with StackID index is 0
+        div_seq = ((1, 1),)
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        assert MFW(fake_mf).image_shape == (32, 64)
+        # Check 2D shape with extraneous extra indices
+        div_seq = ((1, 1, 2),)
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        assert MFW(fake_mf).image_shape == (32, 64)
+        # Check 2D plus time
+        div_seq = ((1, 1, 1), (1, 1, 2), (1, 1, 3))
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        assert MFW(fake_mf).image_shape == (32, 64, 1, 3)
+        # Check 3D shape when StackID index is 0
         div_seq = ((1, 1), (1, 2), (1, 3), (1, 4))
         fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
         assert MFW(fake_mf).image_shape == (32, 64, 4)
-        # Check stack number matching when StackID index is 0
+        # Check fow warning when implicitly dropping stacks
         div_seq = ((1, 1), (1, 2), (1, 3), (2, 4))
         fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        with pytest.warns(
+            UserWarning,
+            match='A multi-stack file was passed without an explicit filter, just using lowest StackID',
+        ):
+            assert MFW(fake_mf).image_shape == (32, 64, 3)
+        # No warning if we expclitly select that StackID to keep
+        assert MFW(fake_mf, frame_filters=(didw.FilterMultiStack(1),)).image_shape == (32, 64, 3)
+        assert MFW(fake_mf, frame_filters=(didw.FilterMultiStack(2),)).image_shape == (32, 64)
+        # Stack filtering is the same when StackID is not an index
+        div_seq = ((1,), (2,), (3,), (4,))
+        sid_seq = (1, 1, 1, 2)
+        fake_mf.update(fake_shape_dependents(div_seq, sid_seq=sid_seq))
+        with pytest.warns(
+            UserWarning,
+            match='A multi-stack file was passed without an explicit filter, just using lowest StackID',
+        ):
+            assert MFW(fake_mf).image_shape == (32, 64, 3)
+        # No warning if we expclitly select that StackID to keep
+        assert MFW(fake_mf, frame_filters=(didw.FilterMultiStack(1),)).image_shape == (32, 64, 3)
+        assert MFW(fake_mf, frame_filters=(didw.FilterMultiStack(2),)).image_shape == (32, 64)
+        # Check for error when explicitly requested StackID is missing
         with pytest.raises(didw.WrapperError):
-            MFW(fake_mf).image_shape
+            MFW(fake_mf, frame_filters=(didw.FilterMultiStack(3),))
         # Make some fake frame data for 4D when StackID index is 0
         div_seq = ((1, 1, 1), (1, 2, 1), (1, 1, 2), (1, 2, 2), (1, 1, 3), (1, 2, 3))
         fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
@@ -497,8 +597,12 @@ class TestMultiFrameWrapper(TestCase):
         # Check stack number matching for 4D when StackID index is 0
         div_seq = ((1, 1, 1), (1, 2, 1), (1, 1, 2), (1, 2, 2), (1, 1, 3), (2, 2, 3))
         fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
-        with pytest.raises(didw.WrapperError):
-            MFW(fake_mf).image_shape
+        with pytest.warns(
+            UserWarning,
+            match='A multi-stack file was passed without an explicit filter, just using lowest StackID',
+        ):
+            with pytest.raises(didw.WrapperError):
+                MFW(fake_mf).image_shape
         # Check indices can be non-contiguous when StackID index is 0
         div_seq = ((1, 1, 1), (1, 2, 1), (1, 1, 3), (1, 2, 3))
         fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
@@ -507,17 +611,22 @@ class TestMultiFrameWrapper(TestCase):
         div_seq = ((1, 1, 0), (1, 2, 0), (1, 1, 3), (1, 2, 3))
         fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
         assert MFW(fake_mf).image_shape == (32, 64, 2, 2)
+        # Check number of IPP vals match the number of slices or we raise
+        frames = fake_mf.PerFrameFunctionalGroupsSequence
+        for frame in frames[1:]:
+            frame.PlanePositionSequence = frames[0].PlanePositionSequence[:]
+        with pytest.raises(didw.WrapperError):
+            MFW(fake_mf).image_shape
+        # Check we raise on missing slices
+        div_seq = ((1, 1, 0), (1, 2, 0), (1, 1, 1))
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        with pytest.raises(didw.WrapperError):
+            MFW(fake_mf).image_shape
         # check 3D shape when there is no StackID index
         div_seq = ((1,), (2,), (3,), (4,))
         sid_seq = (1, 1, 1, 1)
         fake_mf.update(fake_shape_dependents(div_seq, sid_seq=sid_seq))
         assert MFW(fake_mf).image_shape == (32, 64, 4)
-        # check 3D stack number matching when there is no StackID index
-        div_seq = ((1,), (2,), (3,), (4,))
-        sid_seq = (1, 1, 1, 2)
-        fake_mf.update(fake_shape_dependents(div_seq, sid_seq=sid_seq))
-        with pytest.raises(didw.WrapperError):
-            MFW(fake_mf).image_shape
         # check 4D shape when there is no StackID index
         div_seq = ((1, 1), (2, 1), (1, 2), (2, 2), (1, 3), (2, 3))
         sid_seq = (1, 1, 1, 1, 1, 1)
@@ -527,8 +636,12 @@ class TestMultiFrameWrapper(TestCase):
         div_seq = ((1, 1), (2, 1), (1, 2), (2, 2), (1, 3), (2, 3))
         sid_seq = (1, 1, 1, 1, 1, 2)
         fake_mf.update(fake_shape_dependents(div_seq, sid_seq=sid_seq))
-        with pytest.raises(didw.WrapperError):
-            MFW(fake_mf).image_shape
+        with pytest.warns(
+            UserWarning,
+            match='A multi-stack file was passed without an explicit filter, just using lowest StackID',
+        ):
+            with pytest.raises(didw.WrapperError):
+                MFW(fake_mf).image_shape
         # check 3D shape when StackID index is 1
         div_seq = ((1, 1), (2, 1), (3, 1), (4, 1))
         fake_mf.update(fake_shape_dependents(div_seq, sid_dim=1))
@@ -536,16 +649,82 @@ class TestMultiFrameWrapper(TestCase):
         # Check stack number matching when StackID index is 1
         div_seq = ((1, 1), (2, 1), (3, 2), (4, 1))
         fake_mf.update(fake_shape_dependents(div_seq, sid_dim=1))
-        with pytest.raises(didw.WrapperError):
-            MFW(fake_mf).image_shape
+        with pytest.warns(
+            UserWarning,
+            match='A multi-stack file was passed without an explicit filter, just using lowest StackID',
+        ):
+            assert MFW(fake_mf).image_shape == (32, 64, 3)
         # Make some fake frame data for 4D when StackID index is 1
         div_seq = ((1, 1, 1), (2, 1, 1), (1, 1, 2), (2, 1, 2), (1, 1, 3), (2, 1, 3))
         fake_mf.update(fake_shape_dependents(div_seq, sid_dim=1))
         assert MFW(fake_mf).image_shape == (32, 64, 2, 3)
+        # Check non-singular dimension preceding slice dim raises
+        div_seq = ((1, 1, 1), (1, 2, 1), (1, 1, 2), (1, 2, 2), (1, 1, 3), (1, 2, 3))
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0, slice_dim=2))
+        with pytest.raises(didw.WrapperError):
+            MFW(fake_mf).image_shape
+        # Test with combo indices, here with the last two needing to be combined into
+        # a single index corresponding to [(1, 1), (1, 1), (2, 1), (2, 1), (2, 2), (2, 2)]
+        div_seq = (
+            (1, 1, 1, 1),
+            (1, 2, 1, 1),
+            (1, 1, 2, 1),
+            (1, 2, 2, 1),
+            (1, 1, 2, 2),
+            (1, 2, 2, 2),
+        )
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        assert MFW(fake_mf).image_shape == (32, 64, 2, 3)
+        # Test invalid 4D indices
+        div_seq = ((1, 1, 1), (1, 2, 1), (1, 1, 2), (1, 2, 2), (1, 1, 3), (1, 2, 4))
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        with pytest.raises(didw.WrapperError):
+            MFW(fake_mf).image_shape
+        div_seq = ((1, 1, 1), (1, 2, 1), (1, 1, 2), (1, 2, 2), (1, 1, 3), (1, 2, 2))
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        with pytest.raises(didw.WrapperError):
+            MFW(fake_mf).image_shape
+        # Time index that is unique to each frame
+        div_seq = ((1, 1, 1), (1, 2, 2), (1, 1, 3), (1, 2, 4), (1, 1, 5), (1, 2, 6))
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        assert MFW(fake_mf).image_shape == (32, 64, 2, 3)
+        div_seq = (
+            (1, 1, 1, 1),
+            (1, 2, 2, 1),
+            (1, 1, 3, 1),
+            (1, 2, 4, 1),
+            (1, 1, 5, 1),
+            (1, 2, 6, 1),
+            (1, 1, 7, 2),
+            (1, 2, 8, 2),
+            (1, 1, 9, 2),
+            (1, 2, 10, 2),
+            (1, 1, 11, 2),
+            (1, 2, 12, 2),
+        )
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        assert MFW(fake_mf).image_shape == (32, 64, 2, 3, 2)
+        # Check we only allow one extra spatial dimension with unique val per frame
+        div_seq = (
+            (1, 1, 1, 6),
+            (1, 2, 2, 5),
+            (1, 1, 3, 4),
+            (1, 2, 4, 3),
+            (1, 1, 5, 2),
+            (1, 2, 6, 1),
+        )
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        with pytest.raises(didw.WrapperError):
+            MFW(fake_mf).image_shape
+        # Check that having unique value per frame works with single volume
+        div_seq = ((1, 1, 1), (1, 2, 2), (1, 3, 3))
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        assert MFW(fake_mf).image_shape == (32, 64, 3)
 
+    @dicom_test
     def test_iop(self):
         # Test Image orient patient for multiframe
-        fake_mf = copy(self.MINIMAL_MF)
+        fake_mf = deepcopy(self.MINIMAL_MF)
         MFW = self.WRAPCLASS
         dw = MFW(fake_mf)
         with pytest.raises(didw.WrapperError):
@@ -554,84 +733,94 @@ class TestMultiFrameWrapper(TestCase):
         fake_frame = fake_frames(
             'PlaneOrientationSequence', 'ImageOrientationPatient', [[0, 1, 0, 1, 0, 0]]
         )[0]
-        fake_mf['SharedFunctionalGroupsSequence'] = [fake_frame]
+        fake_mf.SharedFunctionalGroupsSequence = [fake_frame]
         assert_array_equal(MFW(fake_mf).image_orient_patient, [[0, 1], [1, 0], [0, 0]])
-        fake_mf['SharedFunctionalGroupsSequence'] = [None]
+        fake_mf.SharedFunctionalGroupsSequence = [pydicom.Dataset()]
         with pytest.raises(didw.WrapperError):
             MFW(fake_mf).image_orient_patient
-        fake_mf['PerFrameFunctionalGroupsSequence'] = [fake_frame]
+        fake_mf.PerFrameFunctionalGroupsSequence = [fake_frame]
         assert_array_equal(MFW(fake_mf).image_orient_patient, [[0, 1], [1, 0], [0, 0]])
 
+    @dicom_test
     def test_voxel_sizes(self):
         # Test voxel size calculation
-        fake_mf = copy(self.MINIMAL_MF)
+        fake_mf = deepcopy(self.MINIMAL_MF)
         MFW = self.WRAPCLASS
         dw = MFW(fake_mf)
         with pytest.raises(didw.WrapperError):
             dw.voxel_sizes
         # Make a fake frame
         fake_frame = fake_frames('PixelMeasuresSequence', 'PixelSpacing', [[2.1, 3.2]])[0]
-        fake_mf['SharedFunctionalGroupsSequence'] = [fake_frame]
+        fake_mf.SharedFunctionalGroupsSequence = [fake_frame]
         # Still not enough, we lack information for slice distances
         with pytest.raises(didw.WrapperError):
             MFW(fake_mf).voxel_sizes
         # This can come from SpacingBetweenSlices or frame SliceThickness
-        fake_mf['SpacingBetweenSlices'] = 4.3
+        fake_mf.SpacingBetweenSlices = 4.3
         assert_array_equal(MFW(fake_mf).voxel_sizes, [2.1, 3.2, 4.3])
         # If both, prefer SliceThickness
         fake_frame.PixelMeasuresSequence[0].SliceThickness = 5.4
         assert_array_equal(MFW(fake_mf).voxel_sizes, [2.1, 3.2, 5.4])
         # Just SliceThickness is OK
-        del fake_mf['SpacingBetweenSlices']
+        del fake_mf.SpacingBetweenSlices
         assert_array_equal(MFW(fake_mf).voxel_sizes, [2.1, 3.2, 5.4])
         # Removing shared leads to error again
-        fake_mf['SharedFunctionalGroupsSequence'] = [None]
+        fake_mf.SharedFunctionalGroupsSequence = [pydicom.Dataset()]
         with pytest.raises(didw.WrapperError):
             MFW(fake_mf).voxel_sizes
         # Restoring to frames makes it work again
-        fake_mf['PerFrameFunctionalGroupsSequence'] = [fake_frame]
+        fake_mf.PerFrameFunctionalGroupsSequence = [fake_frame]
         assert_array_equal(MFW(fake_mf).voxel_sizes, [2.1, 3.2, 5.4])
         # Decimals in any field are OK
         fake_frame = fake_frames(
             'PixelMeasuresSequence', 'PixelSpacing', [[Decimal('2.1'), Decimal('3.2')]]
         )[0]
-        fake_mf['SharedFunctionalGroupsSequence'] = [fake_frame]
-        fake_mf['SpacingBetweenSlices'] = Decimal('4.3')
+        fake_mf.SharedFunctionalGroupsSequence = [fake_frame]
+        fake_mf.SpacingBetweenSlices = Decimal('4.3')
         assert_array_equal(MFW(fake_mf).voxel_sizes, [2.1, 3.2, 4.3])
         fake_frame.PixelMeasuresSequence[0].SliceThickness = Decimal('5.4')
         assert_array_equal(MFW(fake_mf).voxel_sizes, [2.1, 3.2, 5.4])
 
+    @dicom_test
     def test_image_position(self):
         # Test image_position property for multiframe
-        fake_mf = copy(self.MINIMAL_MF)
+        fake_mf = deepcopy(self.MINIMAL_MF)
         MFW = self.WRAPCLASS
         dw = MFW(fake_mf)
         with pytest.raises(didw.WrapperError):
             dw.image_position
         # Make a fake frame
-        fake_frame = fake_frames(
-            'PlanePositionSequence', 'ImagePositionPatient', [[-2.0, 3.0, 7]]
-        )[0]
-        fake_mf['SharedFunctionalGroupsSequence'] = [fake_frame]
+        iop = [0, 1, 0, 1, 0, 0]
+        frames = fake_frames('PlaneOrientationSequence', 'ImageOrientationPatient', [iop])
+        frames = fake_frames(
+            'PlanePositionSequence', 'ImagePositionPatient', [[-2.0, 3.0, 7]], frames
+        )
+        fake_mf.SharedFunctionalGroupsSequence = frames
         assert_array_equal(MFW(fake_mf).image_position, [-2, 3, 7])
-        fake_mf['SharedFunctionalGroupsSequence'] = [None]
+        fake_mf.SharedFunctionalGroupsSequence = [pydicom.Dataset()]
         with pytest.raises(didw.WrapperError):
             MFW(fake_mf).image_position
-        fake_mf['PerFrameFunctionalGroupsSequence'] = [fake_frame]
+        fake_mf.PerFrameFunctionalGroupsSequence = frames
         assert_array_equal(MFW(fake_mf).image_position, [-2, 3, 7])
         # Check lists of Decimals work
-        fake_frame.PlanePositionSequence[0].ImagePositionPatient = [
+        frames[0].PlanePositionSequence[0].ImagePositionPatient = [
             Decimal(str(v)) for v in [-2, 3, 7]
         ]
         assert_array_equal(MFW(fake_mf).image_position, [-2, 3, 7])
         assert MFW(fake_mf).image_position.dtype == float
+        # We should get minimum along slice normal with multiple frames
+        frames = fake_frames('PlaneOrientationSequence', 'ImageOrientationPatient', [iop] * 2)
+        ipps = [[-2.0, 3.0, 7], [-2.0, 3.0, 6]]
+        frames = fake_frames('PlanePositionSequence', 'ImagePositionPatient', ipps, frames)
+        fake_mf.PerFrameFunctionalGroupsSequence = frames
+        assert_array_equal(MFW(fake_mf).image_position, [-2, 3, 6])
 
     @dicom_test
     @pytest.mark.xfail(reason='Not packaged in install', raises=FileNotFoundError)
     def test_affine(self):
         # Make sure we find orientation/position/spacing info
         dw = didw.wrapper_from_file(DATA_FILE_4D)
-        aff = dw.affine
+        dw.affine
 
     @dicom_test
     @pytest.mark.xfail(reason='Not packaged in install', raises=FileNotFoundError)
@@ -645,7 +834,7 @@ class TestMultiFrameWrapper(TestCase):
         if endian_codes[data.dtype.byteorder] == '>':
             data = data.byteswap()
         dat_str = data.tobytes()
-        assert sha1(dat_str).hexdigest() == '149323269b0af92baa7508e19ca315240f77fa8c'
+        assert sha1(dat_str).hexdigest() == 'dc011bb49682fb78f3cebacf965cb65cc9daba7d'
 
     @dicom_test
     def test_slicethickness_fallback(self):
@@ -657,16 +846,16 @@ class TestMultiFrameWrapper(TestCase):
     def test_data_derived_shape(self):
         # Test 4D diffusion data with an additional trace volume included
         # Excludes the trace volume and generates the correct shape
-        dw = didw.wrapper_from_file(DATA_FILE_4D_DERIVED)
         with pytest.warns(UserWarning, match='Derived images found and removed'):
-            assert dw.image_shape == (96, 96, 60, 33)
+            dw = didw.wrapper_from_file(DATA_FILE_4D_DERIVED)
+        assert dw.image_shape == (96, 96, 60, 33)
 
     @dicom_test
     @needs_nibabel_data('dcm_qa_xa30')
     def test_data_trace(self):
         # Test that a standalone trace volume is found and not dropped
         dw = didw.wrapper_from_file(DATA_FILE_SIEMENS_TRACE)
-        assert dw.image_shape == (72, 72, 39, 1)
+        assert dw.image_shape == (72, 72, 39)
 
     @dicom_test
     @needs_nibabel_data('nitest-dicom')
@@ -679,7 +868,7 @@ class TestMultiFrameWrapper(TestCase):
     @dicom_test
     def test_data_fake(self):
         # Test algorithm for get_data
-        fake_mf = copy(self.MINIMAL_MF)
+        fake_mf = deepcopy(self.MINIMAL_MF)
         MFW = self.WRAPCLASS
         dw = MFW(fake_mf)
         # Fails - no shape
@@ -691,8 +880,8 @@ class TestMultiFrameWrapper(TestCase):
         with pytest.raises(didw.WrapperError):
             dw.get_data()
         # Make shape and indices
-        fake_mf['Rows'] = 2
-        fake_mf['Columns'] = 3
+        fake_mf.Rows = 2
+        fake_mf.Columns = 3
         dim_idxs = ((1, 1), (1, 2), (1, 3), (1, 4))
         fake_mf.update(fake_shape_dependents(dim_idxs, sid_dim=0))
         assert MFW(fake_mf).image_shape == (2, 3, 4)
@@ -702,19 +891,24 @@ class TestMultiFrameWrapper(TestCase):
         # Add data - 3D
         data = np.arange(24).reshape((2, 3, 4))
         # Frames dim is first for some reason
-        fake_mf['pixel_array'] = np.rollaxis(data, 2)
+        object.__setattr__(fake_mf, 'pixel_array', np.rollaxis(data, 2))
         # Now it should work
         dw = MFW(fake_mf)
         assert_array_equal(dw.get_data(), data)
         # Test scaling works
-        fake_mf['RescaleSlope'] = 2.0
-        fake_mf['RescaleIntercept'] = -1
+        fake_mf.RescaleSlope = 2.0
+        fake_mf.RescaleIntercept = -1
         assert_array_equal(MFW(fake_mf).get_data(), data * 2.0 - 1)
         # Check slice sorting
         dim_idxs = ((1, 4), (1, 2), (1, 3), (1, 1))
         fake_mf.update(fake_shape_dependents(dim_idxs, sid_dim=0))
         sorted_data = data[..., [3, 1, 2, 0]]
-        fake_mf['pixel_array'] = np.rollaxis(sorted_data, 2)
+        fake_mf.pixel_array = np.rollaxis(sorted_data, 2)
+        assert_array_equal(MFW(fake_mf).get_data(), data * 2.0 - 1)
+        # Check slice sorting with negative index / IPP correlation
+        fake_mf.update(fake_shape_dependents(dim_idxs, sid_dim=0, flip_ipp_idx_corr=True))
+        sorted_data = data[..., [0, 2, 1, 3]]
+        fake_mf.pixel_array = np.rollaxis(sorted_data, 2)
         assert_array_equal(MFW(fake_mf).get_data(), data * 2.0 - 1)
         # 5D!
         dim_idxs = [
@@ -741,28 +935,173 @@ class TestMultiFrameWrapper(TestCase):
         sorted_data = data.reshape(shape[:2] + (-1,), order='F')
         order = [11, 9, 10, 8, 3, 1, 2, 0, 15, 13, 14, 12, 7, 5, 6, 4]
         sorted_data = sorted_data[..., np.argsort(order)]
-        fake_mf['pixel_array'] = np.rollaxis(sorted_data, 2)
+        fake_mf.pixel_array = np.rollaxis(sorted_data, 2)
         assert_array_equal(MFW(fake_mf).get_data(), data * 2.0 - 1)
 
-    def test__scale_data(self):
+    @dicom_test
+    def test_scale_data(self):
         # Test data scaling
-        fake_mf = copy(self.MINIMAL_MF)
+        fake_mf = deepcopy(self.MINIMAL_MF)
+        fake_mf.Rows = 2
+        fake_mf.Columns = 3
+        fake_mf.PerFrameFunctionalGroupsSequence = [pydicom.Dataset() for _ in range(4)]
         MFW = self.WRAPCLASS
-        dw = MFW(fake_mf)
-        data = np.arange(24).reshape((2, 3, 4))
-        assert_array_equal(data, dw._scale_data(data))
-        fake_mf['RescaleSlope'] = 2.0
-        fake_mf['RescaleIntercept'] = -1.0
-        assert_array_equal(data * 2 - 1, dw._scale_data(data))
-        fake_frame = fake_frames('PixelValueTransformationSequence', 'RescaleSlope', [3.0])[0]
-        fake_mf['PerFrameFunctionalGroupsSequence'] = [fake_frame]
-        # Lacking RescaleIntercept -> Error
-        dw = MFW(fake_mf)
-        with pytest.raises(AttributeError):
-            dw._scale_data(data)
-        fake_frame.PixelValueTransformationSequence[0].RescaleIntercept = -2
-        assert_array_equal(data * 3 - 2, dw._scale_data(data))
+        data = np.arange(24).reshape((2, 3, 4), order='F')
+        assert_array_equal(data, MFW(fake_mf)._scale_data(data))
+        # Test legacy top-level slope/intercept
+        fake_mf.RescaleSlope = 2.0
+        fake_mf.RescaleIntercept = -1.0
+        assert_array_equal(data * 2 - 1, MFW(fake_mf)._scale_data(data))
+        # RealWorldValueMapping takes precedence, but only with defined units
+        fake_mf.RealWorldValueMappingSequence = [pydicom.Dataset()]
+        fake_mf.RealWorldValueMappingSequence[0].RealWorldValueSlope = 10.0
+        fake_mf.RealWorldValueMappingSequence[0].RealWorldValueIntercept = -5.0
+        assert_array_equal(data * 2 - 1, MFW(fake_mf)._scale_data(data))
+        fake_mf.RealWorldValueMappingSequence[0].MeasurementUnitsCodeSequence = [pydicom.Dataset()]
+        fake_mf.RealWorldValueMappingSequence[0].MeasurementUnitsCodeSequence[0].CodeMeaning = '%'
+        assert_array_equal(data * 10 - 5, MFW(fake_mf)._scale_data(data))
+        fake_mf.RealWorldValueMappingSequence[0].MeasurementUnitsCodeSequence[
+            0
+        ].CodeMeaning = 'no units'
+        assert_array_equal(data * 2 - 1, MFW(fake_mf)._scale_data(data))
+        # Possible to have more than one RealWorldValueMapping, use first one with defined units
+        fake_mf.RealWorldValueMappingSequence.append(pydicom.Dataset())
+        fake_mf.RealWorldValueMappingSequence[-1].RealWorldValueSlope = 15.0
+        fake_mf.RealWorldValueMappingSequence[-1].RealWorldValueIntercept = -3.0
+        fake_mf.RealWorldValueMappingSequence[-1].MeasurementUnitsCodeSequence = [
+            pydicom.Dataset()
+        ]
+        fake_mf.RealWorldValueMappingSequence[-1].MeasurementUnitsCodeSequence[0].CodeMeaning = '%'
+        assert_array_equal(data * 15 - 3, MFW(fake_mf)._scale_data(data))
+        # A global RWV scale takes precedence over per-frame PixelValueTransformation
+        div_seq = ((1, 1, 1), (1, 2, 1), (1, 1, 2), (1, 2, 2))
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        frames = fake_frames(
+            'PixelValueTransformationSequence',
+            'RescaleSlope',
+            [3.0, 3.0, 3.0, 3.0],
+            fake_mf.PerFrameFunctionalGroupsSequence,
+        )
+        assert_array_equal(data * 15 - 3, MFW(fake_mf)._scale_data(data))
+        # The per-frame PixelValueTransformation takes precedence over plain top-level slope / inter
+        delattr(fake_mf, 'RealWorldValueMappingSequence')
+        assert_array_equal(data * 3, MFW(fake_mf)._scale_data(data))
+        for frame in frames:
+            frame.PixelValueTransformationSequence[0].RescaleIntercept = -2
+        assert_array_equal(data * 3 - 2, MFW(fake_mf)._scale_data(data))
         # Decimals are OK
-        fake_frame.PixelValueTransformationSequence[0].RescaleSlope = Decimal('3')
-        fake_frame.PixelValueTransformationSequence[0].RescaleIntercept = Decimal('-2')
-        assert_array_equal(data * 3 - 2, dw._scale_data(data))
+        for frame in frames:
+            frame.PixelValueTransformationSequence[0].RescaleSlope = Decimal(3)
+            frame.PixelValueTransformationSequence[0].RescaleIntercept = Decimal(-2)
+        assert_array_equal(data * 3 - 2, MFW(fake_mf)._scale_data(data))
+        # A per-frame RWV scaling takes precedence over per-frame PixelValueTransformation
+        for frame in frames:
+            frame.RealWorldValueMappingSequence = [pydicom.Dataset()]
+            frame.RealWorldValueMappingSequence[0].RealWorldValueSlope = 10.0
+            frame.RealWorldValueMappingSequence[0].RealWorldValueIntercept = -5.0
+            frame.RealWorldValueMappingSequence[0].MeasurementUnitsCodeSequence = [
+                pydicom.Dataset()
+            ]
+            frame.RealWorldValueMappingSequence[0].MeasurementUnitsCodeSequence[
+                0
+            ].CodeMeaning = '%'
+        assert_array_equal(data * 10 - 5, MFW(fake_mf)._scale_data(data))
+        # Test varying per-frame scale factors
+        for frame_idx, frame in enumerate(frames):
+            frame.RealWorldValueMappingSequence[0].RealWorldValueSlope = 2 * (frame_idx + 1)
+            frame.RealWorldValueMappingSequence[0].RealWorldValueIntercept = -1 * (frame_idx + 1)
+        assert_array_equal(
+            data * np.array([2, 4, 6, 8]) + np.array([-1, -2, -3, -4]),
+            MFW(fake_mf)._scale_data(data),
+        )
+
+    @dicom_test
+    def test_philips_scale_data(self):
+        fake_mf = deepcopy(self.MINIMAL_MF)
+        fake_mf.Manufacturer = 'Philips'
+        fake_mf.Rows = 2
+        fake_mf.Columns = 3
+        fake_mf.PerFrameFunctionalGroupsSequence = [pydicom.Dataset() for _ in range(4)]
+        MFW = self.WRAPCLASS
+        data = np.arange(24).reshape((2, 3, 4), order='F')
+        # Unlike other manufacturers, public scale factors from Philips without defined
+        # units should not be used. In lieu of this the private scale factor should be
+        # used, which should always be available (modulo deidentification). If we can't
+        # find any of these scale factors a warning is issued.
+        with pytest.warns(
+            UserWarning,
+            match='Unable to find Philips private scale factor, cross-series comparisons may be invalid',
+        ):
+            assert_array_equal(data, MFW(fake_mf)._scale_data(data))
+        fake_mf.RescaleSlope = 2.0
+        fake_mf.RescaleIntercept = -1.0
+        for rescale_type in (None, '', 'US', 'normalized'):
+            if rescale_type is not None:
+                fake_mf.RescaleType = rescale_type
+            with pytest.warns(
+                UserWarning,
+                match='Unable to find Philips private scale factor, cross-series comparisons may be invalid',
+            ):
+                assert_array_equal(data, MFW(fake_mf)._scale_data(data))
+        # Falling back to private scaling doesn't generate error
+        priv_block = fake_mf.private_block(0x2005, 'Philips MR Imaging DD 001', create=True)
+        priv_block.add_new(0xE, 'FL', 3.0)
+        assert_array_equal(data * 3.0, MFW(fake_mf)._scale_data(data))
+        # If the units are defined they take precedence over private scaling
+        fake_mf.RescaleType = 'mrad'
+        assert_array_equal(data * 2 - 1, MFW(fake_mf)._scale_data(data))
+        # A RWV scale factor with defined units takes precdence
+        shared = pydicom.Dataset()
+        fake_mf.SharedFunctionalGroupsSequence = [shared]
+        rwv_map = pydicom.Dataset()
+        rwv_map.RealWorldValueSlope = 10.0
+        rwv_map.RealWorldValueIntercept = -5.0
+        rwv_map.MeasurementUnitsCodeSequence = [pydicom.Dataset()]
+        rwv_map.MeasurementUnitsCodeSequence[0].CodeMeaning = '%'
+        shared.RealWorldValueMappingSequence = [rwv_map]
+        assert_array_equal(data * 10 - 5, MFW(fake_mf)._scale_data(data))
+        # Get rid of valid top-level scale factors, test per-frame scale factors
+        delattr(shared, 'RealWorldValueMappingSequence')
+        delattr(fake_mf, 'RescaleType')
+        del fake_mf[priv_block.get_tag(0xE)]
+        div_seq = ((1, 1, 1), (1, 2, 1), (1, 1, 2), (1, 2, 2))
+        fake_mf.update(fake_shape_dependents(div_seq, sid_dim=0))
+        # Simplest case is all frames have same (valid) scale factor
+        for frame in fake_mf.PerFrameFunctionalGroupsSequence:
+            pix_trans = pydicom.Dataset()
+            pix_trans.RescaleSlope = 2.5
+            pix_trans.RescaleIntercept = -4
+            pix_trans.RescaleType = 'mrad'
+            frame.PixelValueTransformationSequence = [pix_trans]
+        assert_array_equal(data * 2.5 - 4, MFW(fake_mf)._scale_data(data))
+        # If some frames are missing valid scale factors we should get a warning
+        for frame in fake_mf.PerFrameFunctionalGroupsSequence[2:]:
+            delattr(frame.PixelValueTransformationSequence[0], 'RescaleType')
+        with pytest.warns(
+            UserWarning,
+            match='Unable to find Philips private scale factor, cross-series comparisons may be invalid',
+        ):
+            assert_array_equal(
+                data * np.array([2.5, 2.5, 1, 1]) + np.array([-4, -4, 0, 0]),
+                MFW(fake_mf)._scale_data(data),
+            )
+        # We can fall back to private scale factor on frame-by-frame basis
+        for frame in fake_mf.PerFrameFunctionalGroupsSequence:
+            priv_block = frame.private_block(0x2005, 'Philips MR Imaging DD 001', create=True)
+            priv_block.add_new(0xE, 'FL', 7.0)
+        assert_array_equal(
+            data * np.array([2.5, 2.5, 7, 7]) + np.array([-4, -4, 0, 0]),
+            MFW(fake_mf)._scale_data(data),
+        )
+        # Again RWV scale factors take precedence
+        for frame_idx, frame in enumerate(fake_mf.PerFrameFunctionalGroupsSequence):
+            rwv_map = pydicom.Dataset()
+            rwv_map.RealWorldValueSlope = 14.0 - frame_idx
+            rwv_map.RealWorldValueIntercept = 5.0
+            rwv_map.MeasurementUnitsCodeSequence = [pydicom.Dataset()]
+            rwv_map.MeasurementUnitsCodeSequence[0].CodeMeaning = '%'
+            frame.RealWorldValueMappingSequence = [rwv_map]
+        assert_array_equal(
+            data * np.array([14, 13, 12, 11]) + np.array([5, 5, 5, 5]),
+            MFW(fake_mf)._scale_data(data),
+        )
