@@ -1,11 +1,9 @@
-"""Functions / decorators for finding / requiring nibabel-data directory
-"""
+"""Functions / decorators for finding / requiring nibabel-data directory"""
 
 import unittest
 from os import environ, listdir
-from os.path import dirname, exists, isdir
+from os.path import dirname, exists, isdir, realpath
 from os.path import join as pjoin
-from os.path import realpath
 
 
 def get_nibabel_data():
