@@ -12,11 +12,11 @@ Then, in the tests, something like::
     assert_equal(code, 0)
     assert_equal(stdout, b'This script ran OK')
 """
+
 import os
 import sys
-from os.path import dirname, isdir, isfile
+from os.path import dirname, isdir, isfile, pathsep, realpath
 from os.path import join as pjoin
-from os.path import pathsep, realpath
 from subprocess import PIPE, Popen
 
 MY_PACKAGE = __package__
