@@ -276,7 +276,7 @@ def test_slope_inter_castable():
         for out_dtt in NUMERIC_TYPES:
             for klass in (ArrayWriter, SlopeArrayWriter, SlopeInterArrayWriter):
                 arr = np.zeros((5,), dtype=in_dtt)
-                aw = klass(arr, out_dtt)  # no error
+                klass(arr, out_dtt)  # no error
     # Test special case of none finite
     # This raises error for ArrayWriter, but not for the others
     arr = np.array([np.inf, np.nan, -np.inf])
@@ -285,8 +285,8 @@ def test_slope_inter_castable():
             in_arr = arr.astype(in_dtt)
             with pytest.raises(WriterError):
                 ArrayWriter(in_arr, out_dtt)
-            aw = SlopeArrayWriter(arr.astype(in_dtt), out_dtt)  # no error
-            aw = SlopeInterArrayWriter(arr.astype(in_dtt), out_dtt)  # no error
+            SlopeArrayWriter(arr.astype(in_dtt), out_dtt)  # no error
+            SlopeInterArrayWriter(arr.astype(in_dtt), out_dtt)  # no error
     for in_dtt, out_dtt, arr, slope_only, slope_inter, neither in (
         (np.float32, np.float32, 1, True, True, True),
         (np.float64, np.float32, 1, True, True, True),
