@@ -1,5 +1,4 @@
-"""Testing fileholders
-"""
+"""Testing fileholders"""
 
 from io import BytesIO
 
