@@ -23,7 +23,7 @@ _counter = 0
 
 def _as_fname(img):
     global _counter
-    fname = 'img%3d.nii' % _counter
+    fname = f'img{_counter:3d}.nii'
     _counter = _counter + 1
     save(img, fname)
     return fname
@@ -58,7 +58,6 @@ def test_concat():
 
                 # Loop over every possible axis, including None (explicit and implied)
                 for axis in list(range(-(dim - 2), (dim - 1))) + [None, '__default__']:
-
                     # Allow testing default vs. passing explicit param
                     if axis == '__default__':
                         np_concat_kwargs = dict(axis=-1)
