@@ -6,8 +6,8 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-"""Tests for imageglobals module
-"""
+"""Tests for imageglobals module"""
+
 from .. import imageglobals as igs
 
 
