@@ -6,12 +6,11 @@
 #   copyright and license terms.
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-""" Tests for image statistics """
+"""Tests for image statistics"""
 
 import numpy as np
 
-from .. import imagestats
-from .. import Nifti1Image
+from .. import Nifti1Image, imagestats
 
 
 def test_mask_volume():
