@@ -1,5 +1,4 @@
-"""Testing package info
-"""
+"""Testing package info"""
 
 import pytest
 
@@ -15,7 +14,7 @@ def test_pkg_info():
         - nibabel.pkg_info.get_pkg_info
         - nibabel.pkg_info.pkg_commit_hash
     """
-    info = nib.get_info()
+    nib.get_info()
 
 
 def test_version():
@@ -38,7 +37,7 @@ def test_cmp_pkg_version_0():
 
 
 @pytest.mark.parametrize(
-    'test_ver, pkg_ver, exp_out',
+    ('test_ver', 'pkg_ver', 'exp_out'),
     [
         ('1.0', '1.0', 0),
         ('1.0.0', '1.0', 0),
@@ -55,8 +54,6 @@ def test_cmp_pkg_version_0():
         ('1.2.1rc1', '1.2.1', -1),
         ('1.2.1rc1', '1.2.1rc', 1),
         ('1.2.1rc', '1.2.1rc1', -1),
-        ('1.2.1rc1', '1.2.1rc', 1),
-        ('1.2.1rc', '1.2.1rc1', -1),
         ('1.2.1b', '1.2.1a', 1),
         ('1.2.1a', '1.2.1b', -1),
         ('1.2.0+1', '1.2', 1),
