@@ -607,7 +607,7 @@ def test_a2f_nanpos():
 
 def test_a2f_bad_scaling():
     # Test that pathological scalers raise an error
-    NUMERICAL_TYPES = sum([sctypes[key] for key in ['int', 'uint', 'float', 'complex']], [])
+    NUMERICAL_TYPES = sum((sctypes[key] for key in ['int', 'uint', 'float', 'complex']), [])
     for in_type, out_type, slope, inter in itertools.product(
         NUMERICAL_TYPES,
         NUMERICAL_TYPES,
@@ -989,7 +989,7 @@ def test_seek_tell_logic():
 
     class BabyBio(BytesIO):
         def seek(self, *args):
-            raise OSError()
+            raise OSError
 
     bio = BabyBio()
     # Fresh fileobj, position 0, can't seek - error
