@@ -7,6 +7,7 @@
 #
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Contexts for *with* statement providing temporary directories"""
+
 import os
 import tempfile
 from contextlib import contextmanager
@@ -15,7 +16,7 @@ try:
     from contextlib import chdir as _chdir
 except ImportError:  # PY310
 
-    @contextmanager  # type: ignore
+    @contextmanager  # type: ignore[no-redef]
     def _chdir(path):
         cwd = os.getcwd()
         os.chdir(path)
@@ -53,7 +54,7 @@ class TemporaryDirectory(tempfile.TemporaryDirectory):
         >>> os.path.exists(tmpdir)
         False
         """
-        return super().__init__(suffix, prefix, dir)
+        super().__init__(suffix, prefix, dir)
 
 
 @contextmanager
